@@ -33,7 +33,7 @@ func breakdownCmd(ctx *config.RunContext) *cobra.Command {
 
 			ctx.SetContextValue("outputFormat", ctx.Config.Format)
 
-			err = checkRunConfig(ctx.Config)
+			err = checkRunConfig(cmd.ErrOrStderr(), ctx.Config)
 			if err != nil {
 				ui.PrintUsageErrorAndExit(cmd, err.Error())
 			}
@@ -46,7 +46,7 @@ func breakdownCmd(ctx *config.RunContext) *cobra.Command {
 
 	cmd.Flags().Bool("terraform-use-state", false, "Use Terraform state instead of generating a plan. Applicable when path is a Terraform directory")
 	cmd.Flags().String("format", "table", "Output format: json, table, html")
-	cmd.Flags().StringSlice("fields", []string{"monthlyQuantity", "unit", "monthlyCost"}, "Comma separated list of output fields: price,monthlyQuantity,unit,hourlyCost,monthlyCost.\nSupported by table and html output formats")
+	cmd.Flags().StringSlice("fields", []string{"monthlyQuantity", "unit", "monthlyCost"}, "Comma separated list of output fields: all,price,monthlyQuantity,unit,hourlyCost,monthlyCost.\nSupported by table and html output formats")
 
 	_ = cmd.RegisterFlagCompletionFunc("format", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{"table", "json", "html"}, cobra.ShellCompDirectiveDefault
