@@ -32,7 +32,7 @@ func diffCmd(ctx *config.RunContext) *cobra.Command {
 				return err
 			}
 
-			err = checkRunConfig(ctx.Config)
+			err = checkRunConfig(cmd.ErrOrStderr(), ctx.Config)
 			if err != nil {
 				ui.PrintUsageErrorAndExit(cmd, err.Error())
 			}
