@@ -2,10 +2,12 @@ package main
 
 import (
 	"fmt"
-	"github.com/Rhymond/go-money"
+	"io"
 	"os"
 	"strings"
 
+	"github.com/Rhymond/go-money"
+
 	"github.com/infracost/infracost/internal/apiclient"
 	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/config"
@@ -51,7 +53,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		if err != nil {
 			m := fmt.Sprintf("%s\n\n", err)
 			m += fmt.Sprintf("Use the %s flag to specify the path to one of the following:\n", ui.PrimaryString("--path"))
-			m += " - Terraform plan JSON file\n - Terraform directory\n - Terraform plan file"
+			m += " - Terraform plan JSON file\n - Terraform/Terragrunt directory\n - Terraform plan file"
 
 			if cmd.Name() != "diff" {
 				m += "\n - Terraform state JSON file"
@@ -65,7 +67,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		if cmd.Name() == "diff" && provider.Type() == "terraform_state_json" {
 			m := "Cannot use Terraform state JSON with the infracost diff command.\n\n"
 			m += fmt.Sprintf("Use the %s flag to specify the path to one of the following:\n", ui.PrimaryString("--path"))
-			m += " - Terraform plan JSON file\n - Terraform directory\n - Terraform plan file"
+			m += " - Terraform plan JSON file\n - Terraform/Terragrunt directory\n - Terraform plan file"
 			return clierror.NewSanitizedError(errors.New(m), "Cannot use Terraform state JSON with the infracost diff command")
 		}
 
@@ -84,21 +86,15 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 			ctx.SetContextValue("hasUsageFile", true)
 		}
 
-		metadata := config.DetectProjectMetadata(ctx)
-		metadata.Type = provider.Type()
-		provider.AddMetadata(metadata)
-		name := schema.GenerateProjectName(metadata, runCtx.Config.EnableDashboard)
-
-		project := schema.NewProject(name, metadata)
-		err = provider.LoadResources(project, u)
+		providerProjects, err := provider.LoadResources(u)
 		if err != nil {
 			return err
 		}
 
-		projects = append(projects, project)
+		projects = append(projects, providerProjects...)
 
 		if runCtx.Config.SyncUsageFile {
-			err = usage.SyncUsageData(project, u, projectCfg.UsageFile)
+			err = usage.SyncUsageData(projects, u, projectCfg.UsageFile)
 			if err != nil {
 				return err
 			}
@@ -195,7 +191,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		return errors.Wrap(err, "Error generating output")
 	}
 
-	fmt.Printf("%s\n", out)
+	cmd.Printf("%s\n", out)
 
 	return nil
 }
@@ -206,7 +202,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 
 	if cmd.Name() != "infracost" && !hasPathFlag && !hasConfigFile {
 		m := fmt.Sprintf("No path specified\n\nUse the %s flag to specify the path to one of the following:\n", ui.PrimaryString("--path"))
-		m += " - Terraform plan JSON file\n - Terraform directory\n - Terraform plan file\n - Terraform state JSON file"
+		m += " - Terraform plan JSON file\n - Terraform/Terragrunt directory\n - Terraform plan file\n - Terraform state JSON file"
 		m += "\n\nAlternatively, use --config-file to process multiple projects, see https://infracost.io/config-file"
 
 		ui.PrintUsageErrorAndExit(cmd, m)
@@ -243,6 +239,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 
 	if !hasConfigFile {
 		err := cfg.LoadFromEnv()
+
 		if err != nil {
 			return err
 		}
@@ -252,8 +249,11 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 		projectCfg.Path, _ = cmd.Flags().GetString("path")
 		projectCfg.UsageFile, _ = cmd.Flags().GetString("usage-file")
 		projectCfg.TerraformPlanFlags, _ = cmd.Flags().GetString("terraform-plan-flags")
-		projectCfg.TerraformWorkspace, _ = cmd.Flags().GetString("terraform-workspace")
 		projectCfg.TerraformUseState, _ = cmd.Flags().GetBool("terraform-use-state")
+
+		if cmd.Flags().Changed("terraform-workspace") {
+			projectCfg.TerraformWorkspace, _ = cmd.Flags().GetString("terraform-workspace")
+		}
 	}
 
 	cfg.Format, _ = cmd.Flags().GetString("format")
@@ -267,16 +267,16 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 	if cmd.Flags().Changed("fields") {
 		fields, _ := cmd.Flags().GetStringSlice("fields")
 		if len(fields) == 0 {
-			ui.PrintWarningf("fields is empty, using defaults: %s", cmd.Flag("fields").DefValue)
+			ui.PrintWarningf(cmd.ErrOrStderr(), "fields is empty, using defaults: %s", cmd.Flag("fields").DefValue)
 		} else if cfg.Fields != nil && !contains(validFieldsFormats, cfg.Format) {
-			ui.PrintWarning("fields is only supported for table and html output formats")
+			ui.PrintWarning(cmd.ErrOrStderr(), "fields is only supported for table and html output formats")
 		} else if len(fields) == 1 && fields[0] == includeAllFields {
 			cfg.Fields = validFields
 		} else {
 			vf := []string{}
 			for _, f := range fields {
 				if !contains(validFields, f) {
-					ui.PrintWarningf("Invalid field '%s' specified, valid fields are: %s or '%s' to include all fields", f, validFields, includeAllFields)
+					ui.PrintWarningf(cmd.ErrOrStderr(), "Invalid field '%s' specified, valid fields are: %s or '%s' to include all fields", f, validFields, includeAllFields)
 				} else {
 					vf = append(vf, f)
 				}
@@ -288,9 +288,9 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 	return nil
 }
 
-func checkRunConfig(cfg *config.Config) error {
+func checkRunConfig(warningWriter io.Writer, cfg *config.Config) error {
 	if cfg.Format == "json" && cfg.ShowSkipped {
-		ui.PrintWarning("show-skipped is not needed with JSON output format as that always includes them.\n")
+		ui.PrintWarning(warningWriter, "show-skipped is not needed with JSON output format as that always includes them.\n")
 	}
 
 	if cfg.SyncUsageFile {
@@ -301,16 +301,16 @@ func checkRunConfig(cfg *config.Config) error {
 			}
 		}
 		if len(missingUsageFile) == 1 {
-			ui.PrintWarning("Ignoring sync-usage-file as no usage-file is specified.\n")
+			ui.PrintWarning(warningWriter, "Ignoring sync-usage-file as no usage-file is specified.\n")
 		} else if len(missingUsageFile) == len(cfg.Projects) {
-			ui.PrintWarning("Ignoring sync-usage-file since no projects have a usage-file specified.\n")
+			ui.PrintWarning(warningWriter, "Ignoring sync-usage-file since no projects have a usage-file specified.\n")
 		} else if len(missingUsageFile) > 1 {
-			ui.PrintWarning(fmt.Sprintf("Ignoring sync-usage-file for following projects as no usage-file is specified for them: %s.\n", strings.Join(missingUsageFile, ", ")))
+			ui.PrintWarning(warningWriter, fmt.Sprintf("Ignoring sync-usage-file for following projects as no usage-file is specified for them: %s.\n", strings.Join(missingUsageFile, ", ")))
 		}
 	}
 
 	if money.GetCurrency(cfg.Currency) == nil {
-		ui.PrintWarning(fmt.Sprintf("Ignoring unknown currency '%s', using USD.\n", cfg.Currency))
+		ui.PrintWarning(warningWriter, fmt.Sprintf("Ignoring unknown currency '%s', using USD.\n", cfg.Currency))
 		cfg.Currency = "USD"
 	}
 
