@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io/ioutil"
 	"os"
+	"path/filepath"
 
 	"github.com/awslabs/goformation/v4"
 	"github.com/infracost/infracost/internal/providers/cloudformation"
@@ -38,6 +39,10 @@ func Detect(ctx *config.ProjectContext) (schema.Provider, error) {
 		return terraform.NewPlanProvider(ctx), nil
 	}
 
+	if isTerragruntDir(path) {
+		return terraform.NewTerragruntProvider(ctx), nil
+	}
+
 	if isTerraformDir(path) {
 		return terraform.NewDirProvider(ctx), nil
 	}
@@ -101,6 +106,17 @@ func isTerraformPlan(path string) bool {
 	return planFile != nil
 }
 
+func isTerragruntDir(path string) bool {
+	if val, ok := os.LookupEnv("TERRAGRUNT_CONFIG"); ok {
+		if filepath.IsAbs(val) {
+			return config.FileExists(val)
+		}
+		return config.FileExists(filepath.Join(path, val))
+	}
+
+	return config.FileExists(filepath.Join(path, "terragrunt.hcl")) || config.FileExists(filepath.Join(path, "terragrunt.hcl.json"))
+}
+
 func isTerraformDir(path string) bool {
 	return terraform.IsTerraformDir(path)
 }
