@@ -29,7 +29,7 @@ type SchemaItem struct {
 	DefaultValue interface{}
 }
 
-func SyncUsageData(project *schema.Project, existingUsageData map[string]*schema.UsageData, usageFilePath string) error {
+func SyncUsageData(projects []*schema.Project, existingUsageData map[string]*schema.UsageData, usageFilePath string) error {
 	if usageFilePath == "" {
 		return nil
 	}
@@ -37,7 +37,14 @@ func SyncUsageData(project *schema.Project, existingUsageData map[string]*schema
 	if err != nil {
 		return err
 	}
-	syncedResourcesUsage := syncResourcesUsage(project.Resources, usageSchema, existingUsageData)
+
+	// TODO: update this when we properly support multiple projects in usage
+	resources := make([]*schema.Resource, 0)
+	for _, project := range projects {
+		resources = append(resources, project.Resources...)
+	}
+
+	syncedResourcesUsage := syncResourcesUsage(resources, usageSchema, existingUsageData)
 	// yaml.MapSlice is used to maintain the order of keys, so re-running
 	// the code won't change the output.
 	syncedUsageData := yaml.MapSlice{
@@ -89,19 +96,32 @@ func syncResourcesUsage(resources []*schema.Resource, usageSchema map[string][]*
 		for _, usageSchemaItem := range resourceUSchema {
 			usageKey := usageSchemaItem.Key
 			usageValueType := usageSchemaItem.ValueType
-			var usageValue interface{}
-			usageValue = usageSchemaItem.DefaultValue
+			var existingUsageValue interface{}
 			if existingUsage, ok := existingUsageData[resourceName]; ok {
 				switch usageValueType {
 				case schema.Float64:
-					usageValue = existingUsage.Get(usageKey).Float()
+					if v := existingUsage.GetFloat(usageKey); v != nil {
+						existingUsageValue = *v
+					}
 				case schema.Int64:
-					usageValue = existingUsage.Get(usageKey).Int()
+					if v := existingUsage.GetInt(usageKey); v != nil {
+						existingUsageValue = *v
+					}
 				case schema.String:
-					usageValue = existingUsage.Get(usageKey).String()
+					if v := existingUsage.GetString(usageKey); v != nil {
+						existingUsageValue = *v
+					}
+				case schema.StringArray:
+					if v := existingUsage.GetStringArray(usageKey); v != nil {
+						existingUsageValue = *v
+					}
 				}
 			}
-			resourceUsage[usageKey] = usageValue
+			if existingUsageValue != nil {
+				resourceUsage[usageKey] = existingUsageValue
+			} else {
+				resourceUsage[usageKey] = usageSchemaItem.DefaultValue
+			}
 		}
 		syncedResourceUsage[resourceName] = unFlattenHelper(resourceUsage)
 	}
