@@ -89,13 +89,13 @@ build_output_cmd () {
 
 format_cost () {
   cost=$1
-    
+
   if [ -z "$cost" ] || [ "${cost}" = "null" ]; then
     echo "-"
   elif [ "$(echo "$cost < 100" | bc -l)" = 1 ]; then
-    printf "$%0.2f" "$cost"
+    printf "$currency%0.2f" "$cost"
   else
-    printf "$%0.0f" "$cost"
+    printf "$currency%0.0f" "$cost"
   fi
 }
 
@@ -219,9 +219,11 @@ post_to_azure_devops () {
       GITHUB_SHA=$SYSTEM_PULLREQUEST_SOURCECOMMITID
       post_to_github
     elif [ "$BUILD_REPOSITORY_PROVIDER" = "TfsGit" ]; then
+      # See https://docs.microsoft.com/en-us/javascript/api/azure-devops-extension-api/commentthreadstatus
+      azure_devops_comment_status=${azure_devops_comment_status:-4}
       echo "Posting comment to Azure DevOps repo pull-request $SYSTEM_PULLREQUEST_PULLREQUESTID"
       msg="$(build_msg true)"
-      jq -Mnc --arg msg "$msg" '{"comments": [{"parentCommentId": 0, "content": "\($msg)", "commentType": 1}], "status": 4}' | curl -L -X POST -d @- \
+      jq -Mnc --arg msg "$msg" --arg azure_devops_comment_status $azure_devops_comment_status '{"comments": [{"parentCommentId": 0, "content": "\($msg)", "commentType": 1}], "status": $azure_devops_comment_status}' | curl -L -X POST -d @- \
         -H "Content-Type: application/json" \
         -H "Authorization: Bearer $SYSTEM_ACCESSTOKEN" \
         "$SYSTEM_COLLECTIONURI$SYSTEM_TEAMPROJECT/_apis/git/repositories/$BUILD_REPOSITORY_ID/pullRequests/$SYSTEM_PULLREQUEST_PULLREQUESTID/threads?api-version=6.0"
@@ -312,6 +314,16 @@ diff_output=$(cat infracost_output_cmd | sh)
 past_total_monthly_cost=$(jq '[.projects[].pastBreakdown.totalMonthlyCost | select (.!=null) | tonumber] | add' infracost_breakdown.json)
 total_monthly_cost=$(jq '[.projects[].breakdown.totalMonthlyCost | select (.!=null) | tonumber] | add' infracost_breakdown.json)
 diff_cost=$(jq '[.projects[].diff.totalMonthlyCost | select (.!=null) | tonumber] | add' infracost_breakdown.json)
+currency=$(jq -r '.currency | select (.!=null)' infracost_breakdown.json)
+if [ "$currency" = "" ] || [ "$currency" = "USD" ]; then
+  currency="$"
+elif [ "$currency" = "EUR" ]; then
+  currency="€"
+elif [ "$currency" = "GBP" ]; then
+  currency="£"
+else
+  currency="$currency " # Space is needed so output is "INR 123"
+fi
 
 # If both old and new costs are greater than 0
 if [ $(echo "$past_total_monthly_cost > 0" | bc -l) = 1 ] && [ $(echo "$total_monthly_cost > 0" | bc -l) = 1 ]; then
